==> Number-Phone-JP-0.20100701.tar.gz: Number-Phone-JP-0.20100701/lib/Number/Phone/JP/Table/Class1.pm <==
package Number::Phone::JP::Table::Class1;

use strict;
use warnings;

our $VERSION = '0.20100701';

# Table last modified: 2010-07-01
our %TEL_TABLE = (
    # Pref => q<Assoc-Pref-Regex>,
    '01'    => '\d+', # KDDI
    '030'   => '\d+', # ZIP Telecom
    '031'   => '\d+', # アイ・ピー・エス
    '032'   => '\d+', # アイ・ピー・エス
    '033'   => '\d+', # NTTコミュニケーションズ
    '034'   => '\d+', # NTTコミュニケーションズ
    '035'   => '\d+', # NTTコミュニケーションズ
    '036'   => '\d+', # NTT東日本
    '037'   => '\d+', # フュージョンコミュニケーションズ
    '038'   => '\d+', # フュージョンコミュニケーションズ
    '039'   => '\d+', # NTT西日本
    '041'   => '\d+', # ソフトバンクテレコム
    '042'   => '\d+', # ソフトバンクテレコム
    '043'   => '\d+', # ソフトバンクテレコム
    '044'   => '\d+', # ソフトバンクテレコム
    '045'   => '\d+', # ソフトバンクテレコム
    '046'   => '\d+', # ソフトバンクテレコム
    '050'   => '\d+', # UCOM
    '051'   => '\d+', # KDDI
    '052'   => '\d+', # KDDI
    '053'   => '\d+', # KDDI
    '054'   => '\d+', # KDDI
    '055'   => '\d+', # KDDI
    '056'   => '\d+', # KDDI
    '057'   => '\d+', # KDDI
    '060'   => '\d+', # UCOM
    '061'   => '\d+', # ソフトバンクテレコム
    '062'   => '\d+', # ソフトバンクテレコム
    '063'   => '\d+', # ソフトバンクテレコム
    '065'   => '\d+', # ソフトバンクテレコム
    '066'   => '\d+', # ソフトバンクテレコム
    '070'   => '\d+', # KDDI
    '071'   => '\d+', # ベライゾンジャパン
    '072'   => '\d+', # ベライゾンジャパン
    '073'   => '\d+', # 安子の電話
    '074'   => '\d+', # 安子の電話
    '077'   => '\d+', # KDDI
    '080'   => '\d+', # Tシステムズ・ジャパン
    '081'   => '\d+', # フュージョンコミュニケーションズ
    '082'   => '\d+', # フュージョンコミュニケーションズ
    '083'   => '\d+', # ソフトバンクテレコム
    '084'   => '\d+', # ソフトバンクテレコム
    '086'   => '\d+', # 九州通信ネットワーク
    '088'   => '\d+', # ソフトバンクテレコム
    '089'   => '\d+', # Tシステムズ・ジャパン
);

1;
__END__

==> Number-Phone-JP-0.20100906.tar.gz: Number-Phone-JP-0.20100906/lib/Number/Phone/JP/Table/Class1.pm <==
package Number::Phone::JP::Table::Class1;

use strict;
use warnings;

our $VERSION = '0.20100906';

# Table last modified: 2010-09-06
our %TEL_TABLE = (
    # Pref => q<Assoc-Pref-Regex>,
    '01'    => '\d+', # KDDI
    '030'   => '\d+', # ZIP Telecom
    '031'   => '\d+', # アイ・ピー・エス
    '032'   => '\d+', # アイ・ピー・エス
    '033'   => '\d+', # NTTコミュニケーションズ
    '034'   => '\d+', # NTTコミュニケーションズ
    '035'   => '\d+', # NTTコミュニケーションズ
    '036'   => '\d+', # NTT東日本
    '037'   => '\d+', # フュージョンコミュニケーションズ
    '038'   => '\d+', # フュージョンコミュニケーションズ
    '039'   => '\d+', # NTT西日本
    '041'   => '\d+', # ソフトバンクテレコム
    '042'   => '\d+', # ソフトバンクテレコム
    '043'   => '\d+', # ソフトバンクテレコム
    '044'   => '\d+', # ソフトバンクテレコム
    '045'   => '\d+', # ソフトバンクテレコム
    '046'   => '\d+', # ソフトバンクモバイル
    '050'   => '\d+', # UCOM
    '051'   => '\d+', # KDDI
    '052'   => '\d+', # KDDI
    '053'   => '\d+', # KDDI
    '054'   => '\d+', # KDDI
    '055'   => '\d+', # KDDI
    '056'   => '\d+', # KDDI
    '057'   => '\d+', # KDDI
    '060'   => '\d+', # UCOM
    '061'   => '\d+', # ソフトバンクテレコム
    '062'   => '\d+', # ソフトバンクテレコム
    '063'   => '\d+', # ソフトバンクテレコム
    '065'   => '\d+', # ソフトバンクテレコム
    '066'   => '\d+', # ソフトバンクテレコム
    '070'   => '\d+', # KDDI
    '071'   => '\d+', # ベライゾンジャパン
    '072'   => '\d+', # ベライゾンジャパン
    '073'   => '\d+', # 安子の電話
    '074'   => '\d+', # 安子の電話
    '077'   => '\d+', # KDDI
    '080'   => '\d+', # Tシステムズ・ジャパン
    '081'   => '\d+', # フュージョンコミュニケーションズ
    '082'   => '\d+', # フュージョンコミュニケーションズ
    '083'   => '\d+', # ソフトバンクテレコム
    '084'   => '\d+', # ソフトバンクテレコム
    '086'   => '\d+', # 九州通信ネットワーク
    '088'   => '\d+', # ソフトバンクテレコム
    '089'   => '\d+', # Tシステムズ・ジャパン
);

1;
__END__
